==> cms-db_v0.9.tar.gz: admin/upload.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('files');
include('locale.inc.php');
$locale = new LocalizingClass('files');


if (isset($_POST['submit'])) {
	if (strpos($_POST['path'], '..') !== false) die();
	$filename = $_FILES['file']['name'];
	$filename = str_replace(' ', '_', $filename);
	if (!file_exists('../data/files'.$_POST['path'].$filename)) {
		if(is_uploaded_file($_FILES['file']['tmp_name'])) {
			if(copy($_FILES['file']['tmp_name'], '../data/files'.$_POST['path'].$filename)) {
				header('Location:files.php?path='.$_POST['path'].'&'.SID.csrf_protection_get());
			} else {
				include('error.inc.php');
				throw_error(locale('desc_error',true),'files.php?path='.$_POST['path'].'&'.SID.csrf_protection_get());
			}
		} else {
			include('error.inc.php');
			throw_error(locale('desc_error-no-file',true),'files.php?path='.$_POST['path'].'&'.SID.csrf_protection_get());
		}
	} else {
		include('error.inc.php');
		throw_error(locale('desc_error-filename',true),'files.php?path='.$_POST['path'].'&'.SID.csrf_protection_get());
	}
} else {
	$path = $_GET['path'];
	if (strpos($path, '..') !== false) die();
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('title_upload') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css">
	</head>
	<body>

		<h1><?php locale('title_upload') ?></h1>

		<form action="upload.php?<?php echo SID; csrf_protection_get_html() ?>" method="post" enctype="multipart/form-data">
			<fieldset>
				<p>
					<?php
					$display = substr($path, 0, (strlen($path)) - 1);
					$display = locale('desc_folder-root', true) . str_replace('/', ' → ', $display);
					printf(locale('desc_uploadfile',true), $display);
					?>
				</p>
				<p>
					<input type="hidden" name="path" value="<?php echo htmlspecialchars($path) ?>" />
					<input type="file" name="file" />
				</p>
			</fieldset>
			<input type="submit" name="submit" value="<?php locale('button_upload') ?>" />
		</form>

	</body>
</html>
<?php
}
?>

==> cms-db_v0.9.3.tar.gz: admin/upload.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

require_once('path.inc.php');
require_once(CDB_PATH_ADMIN.'/checkphp.inc.php');
require_once(CDB_PATH_ADMIN.'/checkuser.inc.php');

checkuser('files');
require_once(CDB_PATH_ADMIN.'/locale.inc.php');
$locale = new LocalizingClass('files');


if (isset($_POST['submit'])) {
	if (strpos($_POST['path'], '..') !== false) die();
	$filename = $_FILES['file']['name'];
	$filename = str_replace(' ', '_', $filename);
	if (!file_exists('../data/files'.$_POST['path'].$filename)) {
		if(is_uploaded_file($_FILES['file']['tmp_name'])) {
			if(copy($_FILES['file']['tmp_name'], '../data/files'.$_POST['path'].$filename)) {
				header('Location:files.php?path='.$_POST['path'].'&'.SID.csrf_protection_get());
			} else {
				include('error.inc.php');
				throw_error(locale('desc_error',true),'files.php?path='.$_POST['path'].'&'.SID.csrf_protection_get());
			}
		} else {
			include('error.inc.php');
			throw_error(locale('desc_error-no-file',true),'files.php?path='.$_POST['path'].'&'.SID.csrf_protection_get());
		}
	} else {
		include('error.inc.php');
		throw_error(locale('desc_error-filename',true),'files.php?path='.$_POST['path'].'&'.SID.csrf_protection_get());
	}
} else {
	$path = $_GET['path'];
	if (strpos($path, '..') !== false) die();
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('title_upload') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css">
	</head>
	<body>

		<h1><?php locale('title_upload') ?></h1>

		<form action="upload.php?<?php echo SID; csrf_protection_get_html() ?>" method="post" enctype="multipart/form-data">
			<fieldset>
				<p>
					<?php
					$display = substr($path, 0, (strlen($path)) - 1);
					$display = locale('desc_folder-root', true) . str_replace('/', ' → ', $display);
					printf(locale('desc_uploadfile',true), $display);
					?>
				</p>
				<p>
					<input type="hidden" name="path" value="<?php echo htmlspecialchars($path) ?>" />
					<input type="file" name="file" />
				</p>
			</fieldset>
			<input type="submit" name="submit" value="<?php locale('button_upload') ?>" />
		</form>

	</body>
</html>
<?php
}
?>
